diff --git a/README.md b/README.md index c2d9e51..596cb46 100644 --- a/README.md +++ b/README.md @@ -34,17 +34,17 @@ Here are the available commands: | `pause` | Pauses the current session | `{"command": "pause", "password": ""}` | | `resume` | Resumes a paused session | `{"command": "resume", "password": ""}` | | `reset` | Stops and resets the current session | `{"command": "reset", "password": ""}` | -| `updateSettings` | Update Pomodoro settings | `{"command": "updateSettings", "password": "", "settings": {"work": 600, "shortBreak": 60, "longBreak": 300, "sessions": 2}}` | +| `updateSettings` | Update Pomodoro settings | `{"command": "updateSettings", "password": "", "settings": {"focus": 600, "shortBreak": 60, "longBreak": 300, "sessions": 2}}` | #### Update Settings Command (`updateSettings`) -The `updateSettings` command allows clients to modify the Pomodoro timer configuration, including the length of work sessions, short breaks, long breaks, and the total number of sessions in a cycle. This command must include a valid password to be accepted by the server. The updateSettings command can be used when the timer is stopped. +The `updateSettings` command allows clients to modify the Pomodoro timer configuration, including the length of focus sessions, short breaks, long breaks, and the total number of sessions in a cycle. This command must include a valid password to be accepted by the server. The updateSettings command can be used when the timer is stopped. - Fields in the `settings` Object: - - `work`: Length of the work session (in seconds). + - `focus`: Length of the focus session (in seconds). - `shortBreak`: Length of the short break (in seconds). - `longBreak`: Length of the long break (in seconds). - - `sessions`: Total number of work/break sessions in the Pomodoro cycle. + - `sessions`: Total number of focus/break sessions in the Pomodoro cycle. All fields are mandatory and may not be ommitted. @@ -52,14 +52,14 @@ All fields are mandatory and may not be ommitted. The server periodically (every second) sends JSON-encoded messages to all connected clients to update them on the current state of the Pomodoro session. These messages contain the following fields: -- mode: Indicates the current phase of the Pomodoro session ("Work", "ShortBreak", "LongBreak", "End" or "Idle"). +- mode: Indicates the current phase of the Pomodoro session ("Focus", "ShortBreak", "LongBreak", "End" or "Idle"). - "End" is send only once, after all sessions are finished - settings: Contains the current Pomodoro settings: - - work: Length of the work session in seconds (e.g., 1500 for 25 minutes). + - focus: Length of the focus session in seconds (e.g., 1500 for 25 minutes). - shortBreak: Length of the short break in seconds (e.g., 300 for 5 minutes). - longBreak: Length of the long break in seconds (e.g., 900 for 15 minutes). - - sessions: The total number of work/break sessions (e.g., 4). -- session: The current session number (e.g., 1 for the first work session). + - sessions: The total number of focus/break sessions (e.g., 4). +- session: The current session number (e.g., 1 for the first focus session). - time_left: The remaining time for the current mode, in seconds (e.g., 900 for 15 minutes). - ongoing: Whether a Pomodoro session is currently ongoing. - paused: Whether the timer is paused. @@ -67,11 +67,11 @@ The server periodically (every second) sends JSON-encoded messages to all connec | Message Type | Example | | --- | --- | -| Welcome Message | {"mode":"Idle", "settings":{"work":1500, "shortBreak":300, "longBreak":900, "sessions":4}, "session":0, "time_left":1500, "ongoing":false, "paused":false, "version":"0"} | -| Session Running | {"mode":"Work", "settings":{"work":1500, "shortBreak":300, "longBreak":900, "sessions":4}, "session":1, "time_left":900, "ongoing":true, "paused":false, "version":"0"} | -| Session Running | {"mode":"ShortBreak", "settings":{"work":1500, "shortBreak":300, "longBreak":900, "sessions":4}, "session":2, "time_left":50, "ongoing":true, "paused":false, "version":"0"} | -| Session Paused | {"mode":"Work", "settings":{"work":1500, "shortBreak":300, "longBreak":900, "sessions":4}, "session":2, "time_left":456, "ongoing":true, "paused":true, "version":"0"} | -| Session End/Reset | {"mode":"End", "settings":{"work":1500, "shortBreak":300, "longBreak":900, "sessions":4}, "session":0, "time_left":0, "ongoing":false, "paused":false, "version":"0"} | +| Welcome Message | {"mode":"Idle", "settings":{"focus":1500, "shortBreak":300, "longBreak":900, "sessions":4}, "session":0, "time_left":1500, "ongoing":false, "paused":false, "version":"0"} | +| Session Running | {"mode":"Focus", "settings":{"focus":1500, "shortBreak":300, "longBreak":900, "sessions":4}, "session":1, "time_left":900, "ongoing":true, "paused":false, "version":"0"} | +| Session Running | {"mode":"ShortBreak", "settings":{"focus":1500, "shortBreak":300, "longBreak":900, "sessions":4}, "session":2, "time_left":50, "ongoing":true, "paused":false, "version":"0"} | +| Session Paused | {"mode":"Focus", "settings":{"focus":1500, "shortBreak":300, "longBreak":900, "sessions":4}, "session":2, "time_left":456, "ongoing":true, "paused":true, "version":"0"} | +| Session End/Reset | {"mode":"End", "settings":{"focus":1500, "shortBreak":300, "longBreak":900, "sessions":4}, "session":0, "time_left":0, "ongoing":false, "paused":false, "version":"0"} | ## Testing diff --git a/cmd/server/main.go b/cmd/server/main.go index 2024fa2..330afec 100644 --- a/cmd/server/main.go +++ b/cmd/server/main.go @@ -16,10 +16,10 @@ import ( var ( // define CLI flags - listenAddress = flag.String("listenAddress", shared.DefaultServerConfig.ListenAddress, "IP address to listen on") - listenPort = flag.Int("listenPort", shared.DefaultServerConfig.ListenPort, "Port to listen on") - password = flag.String("password", "", "Control password for pomodoro session (optional)") - showVersionFlag = flag.Bool("version", false, "Output version") + listenAddress = flag.String("listenAddress", shared.DefaultServerConfig.ListenAddress, "IP address to listen on") + listenPort = flag.Int("listenPort", shared.DefaultServerConfig.ListenPort, "Port to listen on") + password = flag.String("password", "", "Control password for pomodoro session (optional)") + showVersion = flag.Bool("version", false, "Output version") ) // Start the pomodoro server @@ -27,7 +27,7 @@ func Start() { flag.Parse() // show server and protocl version and exit - if *showVersionFlag { + if *showVersion { fmt.Printf("GoTomato v%s\n", metadata.GoTomatoVersion) fmt.Printf("Protocol-Version: %s\n", metadata.ProtocolVersion) os.Exit(0) diff --git a/index.html b/index.html index f04bf34..a75e885 100644 --- a/index.html +++ b/index.html @@ -40,8 +40,8 @@
-
-
+
+
@@ -98,7 +98,7 @@
document.getElementById("saveButton").addEventListener("click", function () {
// Get the values from the input fields
var password = document.getElementById("password").value;
- var work = parseInt(document.getElementById("workDuration").value);
+ var focus = parseInt(document.getElementById("focusDuration").value);
var shortBreak = parseInt(document.getElementById("shortBreakDuration").value);
var longBreak = parseInt(document.getElementById("longBreakDuration").value);
var sessions = parseInt(document.getElementById("sessions").value);
@@ -108,7 +108,7 @@
command: "updateSettings",
password: password,
settings: {
- work: work,
+ focus: focus,
shortBreak: shortBreak,
longBreak: longBreak,
sessions: sessions
diff --git a/internal/shared/configDefaults.go b/internal/shared/configDefaults.go
index e125da8..5b668cc 100644
--- a/internal/shared/configDefaults.go
+++ b/internal/shared/configDefaults.go
@@ -10,7 +10,7 @@ var DefaultServerConfig = models.ServerConfig{
// The default pomodoro config if nothing else is set
var DefaultPomodoroConfig = models.PomodoroConfig{
- Work: 25 * 60,
+ Focus: 25 * 60,
ShortBreak: 5 * 60,
LongBreak: 15 * 60,
Sessions: 4,
diff --git a/internal/shared/state.go b/internal/shared/state.go
index e21d4d3..00934f5 100644
--- a/internal/shared/state.go
+++ b/internal/shared/state.go
@@ -10,7 +10,7 @@ var State = models.ServerMessage{
Mode: "Idle",
Settings: DefaultPomodoroConfig,
Session: 0,
- TimeLeft: DefaultPomodoroConfig.Work,
+ TimeLeft: DefaultPomodoroConfig.Focus,
Ongoing: false,
Paused: false,
ProtocolVersion: metadata.ProtocolVersion,
diff --git a/internal/websocket/client_commands.go b/internal/websocket/client_commands.go
index bdb6e7a..7149faa 100644
--- a/internal/websocket/client_commands.go
+++ b/internal/websocket/client_commands.go
@@ -10,7 +10,7 @@ import (
)
func checkSettings(settings models.PomodoroConfig) bool {
- return settings.Work > 0 && settings.ShortBreak > 0 && settings.LongBreak > 0 && settings.Sessions > 0
+ return settings.Focus > 0 && settings.ShortBreak > 0 && settings.LongBreak > 0 && settings.Sessions > 0
}
// Listens for commands from a client and handles them
diff --git a/pkg/models/config.go b/pkg/models/config.go
index 1852165..b1a41ac 100644
--- a/pkg/models/config.go
+++ b/pkg/models/config.go
@@ -4,7 +4,7 @@ import "fmt"
// Represents the configuration of a pomodoro
type PomodoroConfig struct {
- Work int `json:"work"` // Length of work sessions in seconds
+ Focus int `json:"focus"` // Length of focus sessions in seconds
ShortBreak int `json:"shortBreak"` // Length of short break in seconds
LongBreak int `json:"longBreak"` // Length of long break in seconds
Sessions int `json:"sessions"` // Number of total sessions
@@ -12,7 +12,7 @@ type PomodoroConfig struct {
// Stringer interface for the PomodocoConfig model
func (c PomodoroConfig) String() string {
- return fmt.Sprintf("{work: %d, short: %d, long: %d, sessions: %d}", c.Work, c.ShortBreak, c.LongBreak, c.Sessions)
+ return fmt.Sprintf("{focus: %d, short: %d, long: %d, sessions: %d}", c.Focus, c.ShortBreak, c.LongBreak, c.Sessions)
}
// Represents the server configuration
diff --git a/pkg/models/server.go b/pkg/models/server.go
index 6aa914a..f495505 100644
--- a/pkg/models/server.go
+++ b/pkg/models/server.go
@@ -2,7 +2,7 @@ package models
// Represents the data sent to the client via WebSocket
type ServerMessage struct {
- Mode string `json:"mode"` // "Idle", "Work", "ShortBreak", "LongBreak" or "End"
+ Mode string `json:"mode"` // "Idle", "Focus", "ShortBreak", "LongBreak" or "End"
Settings PomodoroConfig `json:"settings"` // The currrent pomodoro settings
Session int `json:"session"` // Current session number
TimeLeft int `json:"time_left"` // Remaining time in seconds
diff --git a/internal/pomodoro/pomodoro.go b/internal/pomodoro/pomodoro.go
index a7bcc00..1dc0e46 100644
--- a/internal/pomodoro/pomodoro.go
+++ b/internal/pomodoro/pomodoro.go
@@ -26,7 +26,7 @@ func waitForTimer(t Timer) bool {
}
}
// RunPomodoro iterates the Pomodoro work/break sessions
func RunPomodoro() {
mu.Lock()
shared.State.Ongoing = true
@@ -40,9 +40,9 @@ func RunPomodoro() {
shared.State.Session = session
- // Work
- shared.State.Mode = "Work"
- timer.StartAsync(pomodoroConfig.Work)
+ // Focus
+ shared.State.Mode = "Focus"
+ timer.StartAsync(pomodoroConfig.Focus)
if !waitForTimer(timer) {
break
}
@@ -74,7 +74,7 @@ func RunPomodoro() {
shared.State.Mode = "Idle"
shared.State.Session = 0
- shared.State.TimeLeft = shared.State.Settings.Work
+ shared.State.TimeLeft = shared.State.Settings.Focus
}
func ResetPomodoro() {
@@ -111,6 +111,6 @@ func IsPomodoroPaused() bool {
func UpdateSettings(settings models.PomodoroConfig) {
if settings != (models.PomodoroConfig{}) {
shared.State.Settings = settings
- shared.State.TimeLeft = settings.Work
+ shared.State.TimeLeft = settings.Focus
}
}
@@ -26,7 +26,7 @@ func waitForTimer(t Timer) bool {
}
}
-// RunPomodoro iterates the Pomodoro work/break sessions
+// RunPomodoro iterates the Pomodoro focus/break sessions
func RunPomodoro() {
mu.Lock()